`useradd` module
****************

Fabric tasks
------------

.. autofunction:: django_fabfile.useradd.adduser
.. autofunction:: django_fabfile.useradd.deluser

.. automodule:: django_fabfile.useradd
   :members:
